@@ -1,7 +1,8 @@
 window <- GRanges("chr16:11348649-11349648")
 gene_anno <- createGeneAnnotation(
     window = window,
-    TxDb = TxDb.Hsapiens.UCSC.hg19.knownGene::TxDb.Hsapiens.UCSC.hg19.knownGene
+    TxDb = TxDb.Hsapiens.UCSC.hg19.knownGene::TxDb.Hsapiens.UCSC.hg19.knownGene,
+    OrgDb = "org.Hs.eg.db"
 )
 
 test_that("Output of createGeneAnnotation is correct", {
